@@ -2,6 +2,7 @@ from spifpy.input.binary_file import BinaryFile
 from spifpy.input.dmt_binary_file import DMTBinaryFile
 from spifpy.input.dmt_grey_file import DMTGreyFile
 from spifpy.input.dmt_mono_file import DMTMonoFile
+from spifpy.input.dmt_grey_mono_file import DMTGreyMonoFile
 from spifpy.input.spec.spec_file import SPECFile
 from spifpy.input.twod_file import TwoDFile
 
@@ -9,6 +10,7 @@ __all__ = [
     "BinaryFile",
     "DMTBinaryFile",
     "DMTGreyFile",
+    "DMTGreyMonoFile",
     "DMTMonoFile",
     "SPECFile",
     "TwoDFile",
